@@ -741,15 +741,11 @@ void Sidebar_Widget::submitFormRequest(const char *action,
     browserArguments.postData = formData;
     browserArguments.setDoPost(QByteArray(action).toLower() == "post");
     // boundary?
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    emit getExtension()->openUrlRequest(QUrl(url), arguments, browserArguments);
-#else
     if (getBrowserExtension()) {
         emit getBrowserExtension()->browserOpenUrlRequest(QUrl(url), arguments, browserArguments);
     } else {
         emit getExtension()->openUrlRequest(QUrl(url));
     }
-#endif
 }
 
 void Sidebar_Widget::openUrlRequest(const QUrl &url, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs)
@@ -758,15 +754,11 @@ void Sidebar_Widget::openUrlRequest(const QUrl &url, const KParts::OpenUrlArgume
         return;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    getExtension()->openUrlRequest(url, args, browserArgs);
-#else
     if (getBrowserExtension()) {
         getBrowserExtension()->browserOpenUrlRequest(url, args, browserArgs);
     } else {
         getExtension()->openUrlRequest(url);
     }
-#endif
 
     setStoredCurViewUrl(url);
 }
@@ -774,15 +766,11 @@ void Sidebar_Widget::openUrlRequest(const QUrl &url, const KParts::OpenUrlArgume
 void Sidebar_Widget::createNewWindow(const QUrl &url, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs,
                                      const WindowArgs &windowArgs)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    getExtension()->createNewWindow(url, args, browserArgs, windowArgs);
-#else
     if (getBrowserExtension()) {
         getBrowserExtension()->browserCreateNewWindow(url, args, browserArgs, windowArgs);
     } else {
         getExtension()->createNewWindow(url);
     }
-#endif
 }
 
 void Sidebar_Widget::slotEnableAction(KonqSidebarModule *module, const char *name, bool enabled)
@@ -888,15 +876,11 @@ void Sidebar_Widget::slotPopupMenu(KonqSidebarModule *module,
     m_activeModule = module;
     doEnableActions();
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    emit getExtension()->popupMenu(global, items, args, browserArgs, flags, actionGroups);
-#else
     if (getBrowserExtension()) {
         emit getBrowserExtension()->browserPopupMenuFromFiles(global, items, args, browserArgs, flags, actionGroups);
     } else {
         emit getExtension()->popupMenu(global, items, args, flags, actionGroups);
     }
-#endif
 }
 
 void Sidebar_Widget::slotUrlsDropped(const QList<QUrl> &urls)
