@@ -7,13 +7,13 @@
 #include <QtGlobal>
 
 #include "konqapplication.h"
-#include "konqsettings.h"
+#include "konqembedsettings.h"
 #include <konqueror-version.h>
 #include "konqmainwindow.h"
 #include "KonquerorAdaptor.h"
 #include "konqviewmanager.h"
 #include "konqurl.h"
-#include "konqsettingsxt.h"
+#include "konqsettings.h"
 #include "konqsessionmanager.h"
 #include "konqclosedwindowsmanager.h"
 #include "konqdebug.h"
@@ -78,9 +78,6 @@ KonquerorApplication::KonquerorApplication(int &argc, char **argv)
     , m_activityConsumer(new KActivities::Consumer(this))
 #endif
 {
-    // enable high dpi support
-    setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
     new KonquerorAdaptor; // not really an adaptor
     const QString dbusInterface = QStringLiteral("org.kde.Konqueror.Main");
     QDBusConnection dbus = QDBusConnection::sessionBus();
@@ -221,7 +218,7 @@ void KonquerorApplication::setupParser()
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("silent")}, i18n("Start without a default window, when called without URLs")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("preload")}, i18n("Preload for later use. This mode does not support URLs on the command line")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("profile")}, i18n("Profile to open (DEPRECATED, IGNORED)"), i18n("profile")));
-    m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("sessions")}, i18n("List available sessions")));
+    m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("sessions")}, i18n("List available sessions and exit")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("open-session")}, i18n("Session to open"), i18n("session")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("mimetype")}, i18n("Mimetype to use for this URL (e.g. text/html or inode/directory)"), i18n("mimetype")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("part")}, i18n("Part to use (e.g. khtml or kwebkitpart)"), i18n("service")));
@@ -230,16 +227,15 @@ void KonquerorApplication::setupParser()
 #ifdef DEVELOPER_MODE
     m_parser.addOption(QCommandLineOption({QStringLiteral("force-new-process")}, i18n("Create a new Konqueror process, even if one already exists. Meant to be used only when developing Konqueror itself")));
 #endif
-    m_parser.addOption(QCommandLineOption({QStringLiteral("test-restore")}, i18n("TEST")));
     m_parser.addPositionalArgument(QStringLiteral("[URL]"), i18n("Location to open"));
 }
 
 static void fixOldStartUrl() {
-    QUrl startUrl(KonqSettings::startURL());
+    QUrl startUrl(Konq::Settings::startURL());
     if (startUrl.scheme() == "about") {
         startUrl.setScheme(KonqUrl::scheme());
-        KonqSettings::setStartURL(startUrl.url());
-        KonqSettings::self()->save();
+        Konq::Settings::setStartURL(startUrl.url());
+        Konq::Settings::self()->save();
     }
 }
 
@@ -264,7 +260,7 @@ int KonquerorApplication::startFirstInstance()
     const int ret = exec();
 
     //Don't preload if Konqueror is run as root
-    bool alwaysPreload = m_runningAsRootBehavior == NotRoot && KonqSettings::alwaysHavePreloaded();
+    bool alwaysPreload = m_runningAsRootBehavior == NotRoot && Konq::Settings::alwaysHavePreloaded();
 
     // Delete all KonqMainWindows, so that we don't have
     // any parts loaded when KLibLoader::cleanUp is called.
@@ -301,6 +297,14 @@ int KonquerorApplication::start()
     m_parser.process(*this);
     m_aboutData.processCommandLine(&m_parser);
 
+    //This can't be done in performStart, because it must be done before creating the
+    //DBus service. Otherwise, the list of session will be printed in the standard output
+    //of the first instance rather than where the command was entered
+    if (m_parser.isSet("sessions")) {
+        listSessions();
+        return 0;
+    }
+
 #ifdef DEVELOPER_MODE
     bool forceNewProcess = m_runningAsRootBehavior != NotRoot || m_parser.isSet(QStringLiteral("force-new-process"));
 #else
@@ -331,10 +335,8 @@ int KonquerorApplication::performStart(const QString& workingDirectory, bool fir
 {
     const QStringList args = m_parser.positionalArguments();
 
-    if (m_parser.isSet("sessions")) {
-        listSessions();
-        return 0;
-    } else if (m_parser.isSet("open-session")) {
+    //NOTE: we don't check for the "session" option because it has already been handled in start()
+    if (m_parser.isSet("open-session")) {
         //If the given session can't be opened for any reason, inform the user
         QString sessionName = m_parser.value("open-session");
         int result = openSession(sessionName);
@@ -519,7 +521,7 @@ void KonquerorApplication::listSessions()
     QTextStream ts(stdout, QIODevice::WriteOnly);
     while (it.hasNext()) {
         QFileInfo fileInfo(it.next());
-        ts << fileInfo.baseName();
+        ts << fileInfo.baseName() << '\n';
     }
 }
 
